##########
Feynmanium
##########

|Codacy Badge| |pre-commit.ci status| |Total alerts| |Language grade: Python| |Code style: black|

A `Discord`_ bot that works.

************
Requirements
************

Feynmanium requires:

-  `Python`_ v3.10 or later
-  `Poetry`_ v1.1 or later

************
Installation
************

Run the following commands to install Feynmanium:

::

   git clone https://github.com/tb148/feynmanium.git
   poetry install

*****
Usage
*****

Run the following commmand to run Feynmanium

::

   python -m feynmanium <token>

.. _Discord: https://discord.com/
.. _Python: https://python.org/
.. _Poetry: https://python-poetry.org/

.. |Codacy Badge| image:: https://app.codacy.com/project/badge/Grade/3f036df7eb36457d8182c08085e42953
   :target: https://www.codacy.com/gh/tb148/feynmanium/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=tb148/feynmanium&amp;utm_campaign=Badge_Grade
.. |pre-commit.ci status| image:: https://results.pre-commit.ci/badge/github/tb148/feynmanium/trunk.svg
   :target: https://results.pre-commit.ci/latest/github/tb148/feynmanium/trunk
.. |Total alerts| image:: https://img.shields.io/lgtm/alerts/g/tb148/feynmanium.svg?logo=lgtm&logoWidth=18
   :target: https://lgtm.com/projects/g/tb148/feynmanium/alerts/
.. |Language grade: Python| image:: https://img.shields.io/lgtm/grade/python/g/tb148/feynmanium.svg?logo=lgtm&logoWidth=18
   :target: https://lgtm.com/projects/g/tb148/feynmanium/context:python
.. |Code style: black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black